==> ext_info-1.2.tar.bz2: ext_info/extlist.h <==
#ifndef EXTINFOITEM_H
#define EXTINFOITEM_H

#define EXTINFO_VERSION "1.2"

#include <qobject.h>
#include <qstring.h>
/**
@author Micha "NKG" Niedwiecki
*/

class ExtListElement
{
    private:
        bool know_birthday;
        bool know_name_day;
        static int daysToAnniversary(const QString& date);
    public:
        QString nickname;
        QString last_name;
        QString first_name;
        QString birthday;
        QString name_day;
        QString phone;
        QString mobile;
        QString city;
        QString street;
        QString interests;
        QString email[2];
        QString www;
        QString irc;
        QString wp;
        QString icq;
        QString tlen;
        QString alt_gg;
        QString memo;
        QString photo_path;
        bool photo_scaled;

        ExtListElement();
        ExtListElement(const ExtListElement& src);

        int daysToBirthday();
        int daysToNameDay();
        void setKnowBirthday() {know_birthday = true;}
        void setKnowNameDay() {know_name_day = true;}
};

class ExtList : public QMap<QString,ExtListElement>
{
    public:
        ExtList(const QString& file = "");
        ExtList(const ExtList &src);

        bool saveToFile(const QString fileName = "");
        bool loadFromFile(const QString fileName = "");
        void setFileName(const QString fileName) {FileName = fileName;}

        void renameItem(const QString& oldName, const QString& newName);

        ExtList getCommingBirthday(int maxdays);
        ExtList getCommingNameDay(int maxdays);

        ExtList& operator=(const ExtList& src);
    private:
        QString FileName;
};

#endif

==> ext_info-1.4.3.tar.bz2: ext_info/extlist.h <==
#ifndef EXTINFOITEM_H
#define EXTINFOITEM_H

#define EXTINFO_VERSION "1.4.3"

#include "config.h"

#if defined(KADU_VERSION_0_4_0_cvs) || \
  defined(KADU_VERSION_0_4_0) || \
  defined(KADU_VERSION_0_4_1) || \
  defined(KADU_VERSION_0_4_2) || \
  defined(KADU_VERSION_0_4_3) || \
  defined(KADU_VERSION_0_4_2_svn) || \
  defined(KADU_VERSION_0_4_3_svn)

#define KADU_0_4_x
#elif defined(KADU_VERSION_0_5_0_svn) || defined(KADU_VERSION_0_5_0)
#define KADU_0_5_0
#endif

#include <qobject.h>
#include <qstring.h>
/**
@author Micha "Dwiedziu" Niedwiecki
*/

class ExtListElement
{
    private:
        bool know_birthday;
        bool know_name_day;
        static int daysToAnniversary(const QString& date);
    public:
        bool modified;

        QString nickname;
        QString last_name;
        QString first_name;
        QString birthday;
        QString name_day;
        QString phone;
        QString mobile;
        QString city;
        QString street;
        QString interests;
        QString email[2];
        QString www;
        QString irc;
        QString wp;
        QString icq;
        QString tlen;
        QString alt_gg;
        QString memo;
        QString photo_path;
        bool photo_scaled;

        ExtListElement();
        ExtListElement(const ExtListElement& src);

        int daysToBirthday() const;
        int daysToNameDay() const;
        void setKnowBirthday() {know_birthday = true;}
        void setKnowNameDay() {know_name_day = true;}
        ExtListElement& operator=(const ExtListElement& src);
        bool operator==(const ExtListElement& src) const;
        bool operator!=(const ExtListElement& src) const {return (!(*this == src));}
};

class ExtList : public QMap<QString,ExtListElement>
{
    public:
        ExtList(const QString& file = "");
        ExtList(const ExtList &src);

        bool saveToFile(const QString fileName = "");
        bool loadFromFile(const QString fileName = "");
        void setFileName(const QString fileName) {FileName = fileName;}

        void renameItem(const QString& oldName, const QString& newName);

        ExtList getCommingBirthday(int maxdays);
        ExtList getCommingNameDay(int maxdays);

        ExtList& operator=(const ExtList& src);
    private:
        QString FileName;
};

#endif
